@@ -91,12 +91,12 @@ PhoneUIBox::PhoneUIBox(MythMainWindow *parent, QString window_name,
     sipStack->UiWatch(DirContainer->ListAllEntries(true));
 
     // Possibly (user-defined) control the volume
-    volume_control = NULL;
+//    volume_control = NULL;
     volume_display_timer = new QTimer(this);
     VolumeMode = VOL_VOLUME;
     volume_icon->SetImage(gContext->FindThemeDir("default") + "/mp_volume_icon.png");
     volume_icon->LoadImage();
-    volume_control = new VolumeControl(true);
+//    volume_control = new VolumeControl(true);
     connect(volume_display_timer, SIGNAL(timeout()), this, SLOT(hideVolume()));
     
     rtpAudio = 0;
@@ -156,8 +156,8 @@ PhoneUIBox::PhoneUIBox(MythMainWindow *parent, QString window_name,
     addDirectoryPopup = NULL;
     incallPopup = NULL;
     statsPopup = NULL;
-    audioPkInOutLabel = audioBytesInOutLabel = audioAvgBwLabel = 0;
-    videoResLabel = videoPkOutLabel = videoPkInLabel = videoBytesInOutLabel = videoAvgBwLabel = videoFramesInOutDiscLabel = videoAvgFpsLabel = videoWebcamFpsLabel = 0;
+    audioPkInOutLabel = audioPlayoutLabel = audioPkRtcpLabel = 0;
+    videoResLabel = videoPkOutLabel = videoPkInLabel = videoPkRtcpLabel = videoFramesInOutDiscLabel = videoAvgFpsLabel = videoWebcamFpsLabel = 0;
     currentCallEntry = 0;
 
     // Used to load voicemail messages in and play them
@@ -411,6 +411,16 @@ QString spk;
         }
         break;
 
+    case RtpEvent::RtpRtcpStatsEv:
+        {
+            RtpEvent *re = (RtpEvent *)event;
+            if (re->owner() == rtpAudio)
+                ProcessAudioRtcpStatistics(re);
+            else if (re->owner() == rtpVideo)
+                ProcessVideoRtcpStatistics(re);
+        }
+        break;
+
     case SipEvent::SipStateChange:
         ProcessSipStateChange();
         break;
@@ -479,29 +489,21 @@ QString spk;
     QWidget::customEvent(event);
 }
 
-
-void PhoneUIBox::PlaceorAnswerCall(QString url, QString name, QString Mode, bool onLocalLan)
+void PhoneUIBox::PlaceCall(QString url, QString name, QString Mode, bool onLocalLan)
 {
-    switch (State)
-    {
-    case SIP_IDLE:
-        sipStack->PlaceNewCall(Mode, url, name, onLocalLan);
+    sipStack->PlaceNewCall(Mode, url, name, onLocalLan);
 
-        // Add an entry into the Placed Calls dir
-        if (currentCallEntry)
-            delete currentCallEntry;
-        currentCallEntry = new CallRecord(name, url, false, (QDateTime::currentDateTime()).toString());
-        phoneUIStatusBar->updateMidCallCaller(((name != 0) && (name.length() > 0)) ? name : url);
-        break;
-
-    case SIP_ICONNECTING:
-        sipStack->AnswerRingingCall(Mode, onLocalLan);
-        break;
-    default:
-        break;
-    }
+    // Add an entry into the Placed Calls dir
+    if (currentCallEntry)
+        delete currentCallEntry;
+    currentCallEntry = new CallRecord(name, url, false, (QDateTime::currentDateTime()).toString());
+    phoneUIStatusBar->updateMidCallCaller(((name != 0) && (name.length() > 0)) ? name : url);
 }
 
+void PhoneUIBox::AnswerCall(QString Mode, bool onLocalLan)
+{
+    sipStack->AnswerRingingCall(Mode, onLocalLan);
+}
 
 void PhoneUIBox::keypadPressed(char k)
 {
@@ -538,7 +540,7 @@ void PhoneUIBox::StartVideo(int lPort, QString remoteIp, int remoteVideoPort, in
 {
     videoCifModeToRes(rxVidRes, rxWidth, rxHeight);
 
-    rtpVideo = new rtp (this, lPort, remoteIp, remoteVideoPort, videoPayload, -1, "", "", RTP_TX_VIDEO, RTP_RX_VIDEO);
+    rtpVideo = new rtp (this, lPort, remoteIp, remoteVideoPort, videoPayload, -1, -1, "", "", RTP_TX_VIDEO, RTP_RX_VIDEO);
 
     if (h263->H263StartEncoder(txWidth, txHeight, txFps) && 
         h263->H263StartDecoder(rxWidth, rxHeight))
@@ -632,7 +634,8 @@ void PhoneUIBox::LoopbackButtonPushed()
         phoneUIStatusBar->DisplayCallState(QString(tr("Audio and Video Looped to ") + loopIp));
         int lvPort = atoi((const char *)gContext->GetSetting("VideoLocalPort"));
         int laPort = atoi((const char *)gContext->GetSetting("AudioLocalPort"));
-        rtpAudio = new rtp (this, laPort, loopIp, laPort, 0, -1, 
+        int playout = atoi((const char *)gContext->GetSetting("PlayoutVideoCall"));
+        rtpAudio = new rtp (this, laPort, loopIp, laPort, 0, playout, -1, 
                             gContext->GetSetting("MicrophoneDevice"), 
                             gContext->GetSetting("AudioOutputDevice"));
         powerDispTimer->start(100);
@@ -908,7 +911,8 @@ void PhoneUIBox::ProcessAudioRtpStatistics(RtpEvent *stats)
                                               stats->getPeriod());
     updateAudioStatistics(stats->getPkIn(), stats->getPkMissed(), stats->getPkLate(), 
                           stats->getPkOut(), stats->getPkInDisc(), stats->getPkOutDrop(), 
-                          stats->getBytesIn(), stats->getBytesOut());
+                          stats->getBytesIn(), stats->getBytesOut(),
+                          stats->getMinPlayout(), stats->getAvgPlayout(), stats->getMaxPlayout());
 }
 
 
@@ -926,6 +930,20 @@ void PhoneUIBox::ProcessVideoRtpStatistics(RtpEvent *stats)
 }
 
 
+void PhoneUIBox::ProcessAudioRtcpStatistics(RtpEvent *stats)
+{
+    updateAudioRtcpStatistics(stats->getRtcpFractionLoss(), stats->getRtcpTotalLoss());
+}
+
+
+void PhoneUIBox::ProcessVideoRtcpStatistics(RtpEvent *stats)
+{
+    updateVideoRtcpStatistics(stats->getRtcpFractionLoss(), stats->getRtcpTotalLoss());
+    if (stats->getRtcpFractionLoss() > 0)
+        h263->H263ForceIFrame();
+}
+
+
 void PhoneUIBox::startRTP(int audioPayload, int videoPayload, int dtmfPayload, int audioPort, int videoPort, 
                           QString remoteIp, QString audioCodec, QString videoCodec, QString videoRes)
 {
@@ -934,7 +952,10 @@ void PhoneUIBox::startRTP(int audioPayload, int videoPayload, int dtmfPayload, i
         int laPort = atoi((const char *)gContext->GetSetting("AudioLocalPort"));
         QString spk = gContext->GetSetting("AudioOutputDevice");
         QString mic = gContext->GetSetting("MicrophoneDevice");
-        rtpAudio = new rtp (this, laPort, remoteIp, audioPort, audioPayload, dtmfPayload, mic, spk);
+        int playout = (videoPayload != -1) ?
+                        atoi((const char *)gContext->GetSetting("PlayoutVideoCall")) :
+                        atoi((const char *)gContext->GetSetting("PlayoutAudioCall"));
+        rtpAudio = new rtp (this, laPort, remoteIp, audioPort, audioPayload, playout, dtmfPayload, mic, spk);
         OnScreenClockTimer->start(1000);
         phoneUIStatusBar->DisplayInCallStats(true);
         phoneUIStatusBar->updateMidCallAudioCodec(audioCodec);
@@ -1003,7 +1024,7 @@ void PhoneUIBox::alertUser(QString callerUser, QString callerName, QString calle
     
     bool AutoanswerEnabled = gContext->GetNumSetting("SipAutoanswer",1);
     if ((AutoanswerEnabled) && (entry)) // Only allow autoanswer from matched entries
-        PlaceorAnswerCall(entry->getUri(), entry->getNickName(), txVideoMode, true);
+        AnswerCall(txVideoMode, true);
     else
     {
         // Popup the caller's details
@@ -1303,7 +1324,7 @@ void PhoneUIBox::closeUrlPopup()
 
 void PhoneUIBox::dialUrlVideo()
 {
-    PlaceorAnswerCall(urlField==0 ? urlRemoteField->text() : urlField->text(), "", txVideoMode);
+    PlaceCall(urlField==0 ? urlRemoteField->text() : urlField->text(), "", txVideoMode);
     closeUrlPopup();                           
 
     // If we got here via the menu popup
@@ -1315,7 +1336,7 @@ void PhoneUIBox::dialUrlVideo()
 
 void PhoneUIBox::dialUrlVoice()
 {
-    PlaceorAnswerCall(urlField==0 ? urlRemoteField->text() : urlField->text(), "", "AUDIOONLY");
+    PlaceCall(urlField==0 ? urlRemoteField->text() : urlField->text(), "", "AUDIOONLY");
     closeUrlPopup();
 
     // If we got here via the menu popup
@@ -1694,14 +1715,26 @@ void PhoneUIBox::doCallPopup(DirEntry *entry, QString DialorAnswer, bool audioOn
             drawCallPopupCallHistory(incallPopup, RecentCalls.prev());
         }
     
-        if (!audioOnly)
-        {
-            QButton *button1 = incallPopup->addButton(DialorAnswer + tr(" Videocall"), this, SLOT(incallDialVideoSelected()));
-            button1->setFocus();
-        }
-        QButton *button2 = incallPopup->addButton(DialorAnswer + tr(" Voice-Only"), this, SLOT(incallDialVoiceSelected()));
+        QButton *button2=0;
         if (DialorAnswer == "Dial")
+        {
+            if (!audioOnly)
+            {
+                QButton *button1 = incallPopup->addButton(DialorAnswer + tr(" Videocall"), this, SLOT(outcallDialVideoSelected()));
+                button1->setFocus();
+            }
+            button2 = incallPopup->addButton(DialorAnswer + tr(" Voice-Only"), this, SLOT(outcallDialVoiceSelected()));
             incallPopup->addButton(tr("Send an Instant Message"), this, SLOT(incallSendIMSelected()));
+        }
+        else
+        {
+            if (!audioOnly)
+            {
+                QButton *button1 = incallPopup->addButton(DialorAnswer + tr(" Videocall"), this, SLOT(incallDialVideoSelected()));
+                button1->setFocus();
+            }
+            button2 = incallPopup->addButton(DialorAnswer + tr(" Voice-Only"), this, SLOT(incallDialVoiceSelected()));
+        }
         
         if (audioOnly)
             button2->setFocus();
@@ -1722,17 +1755,29 @@ void PhoneUIBox::closeCallPopup()
 
 void PhoneUIBox::incallDialVideoSelected()
 {
-    PlaceorAnswerCall(callLabelUrl->text(), callLabelName->text(), txVideoMode, entryIsOnLocalLan);
+    AnswerCall(txVideoMode, entryIsOnLocalLan);
     closeCallPopup();
 }
  
 void PhoneUIBox::incallDialVoiceSelected()
 {
-    PlaceorAnswerCall(callLabelUrl->text(), callLabelName->text(), "AUDIOONLY", entryIsOnLocalLan);
+    AnswerCall("AUDIOONLY", entryIsOnLocalLan);
     closeCallPopup();
 }
 
-void PhoneUIBox::incallSendIMSelected()
+void PhoneUIBox::outcallDialVideoSelected()
+{
+    PlaceCall(callLabelUrl->text(), callLabelName->text(), txVideoMode, entryIsOnLocalLan);
+    closeCallPopup();
+}
+ 
+void PhoneUIBox::outcallDialVoiceSelected()
+{
+    PlaceCall(callLabelUrl->text(), callLabelName->text(), "AUDIOONLY", entryIsOnLocalLan);
+    closeCallPopup();
+}
+
+void PhoneUIBox::outcallSendIMSelected()
 {
     QString OtherParty = callLabelUrl->text();
     closeCallPopup();
@@ -1785,8 +1830,8 @@ void PhoneUIBox::showStatistics(bool showVideo)
 
     statsPopup->addLabel(tr("Audio"), MythPopupBox::Medium);
     audioPkInOutLabel    = statsPopup->addLabel(tr("Packets In/Out/Lost/Late:             "), MythPopupBox::Small);
-    // (not useful) audioBytesInOutLabel = statsPopup->addLabel("KBytes In/Out: ", MythPopupBox::Small);
-    audioAvgBwLabel      = statsPopup->addLabel(tr("Average Kbps In/Out: "), MythPopupBox::Small);
+    audioPlayoutLabel    = statsPopup->addLabel(tr("Playout Delay Min/Avg/Max:            "), MythPopupBox::Small);
+    audioPkRtcpLabel     = statsPopup->addLabel(tr("Packets Lost by Peer:                 "), MythPopupBox::Small);
 
     if (showVideo)
     {
@@ -1797,8 +1842,7 @@ void PhoneUIBox::showStatistics(bool showVideo)
                                                      MythPopupBox::Small);
         videoPkInLabel        = statsPopup->addLabel(tr("Packets In/Lost/Disc/Late: "), MythPopupBox::Small);
         videoPkOutLabel       = statsPopup->addLabel(tr("Packets Out/Dropped: "), MythPopupBox::Small);
-        // (not useful) videoBytesInOutLabel  = statsPopup->addLabel("KBytes In/Out: ", MythPopupBox::Small);
-        videoAvgBwLabel       = statsPopup->addLabel(tr("Average Kbps In/Out: "), MythPopupBox::Small);
+        videoPkRtcpLabel      = statsPopup->addLabel(tr("Packets Lost by Peer: "), MythPopupBox::Small);
         videoFramesInOutDiscLabel = statsPopup->addLabel(tr("Video Frames In/Out/Disc: "), MythPopupBox::Small);
         videoAvgFpsLabel      = statsPopup->addLabel(tr("Average FPS In/Out: "), MythPopupBox::Small);
         videoWebcamFpsLabel   = statsPopup->addLabel(tr("Webcam Frames Delivered/Dropped: "), MythPopupBox::Small);
@@ -1810,25 +1854,36 @@ void PhoneUIBox::showStatistics(bool showVideo)
     statsPopup->ShowPopup(this, SLOT(closeStatisticsPopup()));
 }
 
-
-void PhoneUIBox::updateAudioStatistics(int pkIn, int pkLost, int pkLate, int pkOut, int pkInDisc, int pkOutDrop, int bIn, int bOut)
+void PhoneUIBox::updateAudioStatistics(int pkIn, int pkLost, int pkLate, int pkOut, int pkInDisc, int pkOutDrop, int bIn, int bOut, int minPlayout, int avgPlayout, int maxPlayout)
 {
     (void)pkInDisc;
     (void)pkOutDrop;
+    (void)bIn;
+    (void)bOut;
     if (!statsPopup)
         return;
 
     audioPkInOutLabel->setText(tr("Packets In/Out/Lost/Late: ") + QString::number(pkIn) + " / " + 
                                QString::number(pkOut) + " / " + QString::number(pkLost)
                                + " / " + QString::number(pkLate));
-    //audioBytesInOutLabel->setText("KBytes In/Out: " + QString::number(bIn/1000) + "K / " + QString::number(bOut/1000) + "K");
-    if (ConnectTime.elapsed()/1000 != 0)
-        audioAvgBwLabel->setText (tr("Average Kbps In/Out:") + QString::number(bIn/ConnectTime.elapsed()/1000*8/1000) + "kbps / " + QString::number(bOut/ConnectTime.elapsed()/1000*8/1000) + "kbps");
+    audioPlayoutLabel->setText(tr("Playout Delay Min/Avg/Max: ") + QString::number(minPlayout) + " / " + 
+                               QString::number(avgPlayout) + " / " + QString::number(maxPlayout));
+}
+
+
+void PhoneUIBox::updateAudioRtcpStatistics(int fractionLoss, int totalLoss)
+{
+    if (!statsPopup)
+        return;
+
+    audioPkRtcpLabel->setText(tr("Packets Lost by Peer: ") + QString::number(fractionLoss) + " / " + QString::number(totalLoss));
 }
 
 
 void PhoneUIBox::updateVideoStatistics(int pkIn, int pkLost, int pkLate, int pkOut, int pkInDisc, int pkOutDrop, int bIn, int bOut, int fIn, int fOut, int fDiscIn, int fDiscOut)
 {
+    (void)bIn;
+    (void)bOut;
     if ((!statsPopup) || (videoPkInLabel == 0))
         return;
 
@@ -1837,17 +1892,23 @@ void PhoneUIBox::updateVideoStatistics(int pkIn, int pkLost, int pkLate, int pkO
                                 + " / " + QString::number(pkLate));
     videoPkOutLabel->setText(tr("Packets Out/Dropped: ") + QString::number(pkOut) + " / " + 
                                QString::number(pkOutDrop));
-    //videoBytesInOutLabel->setText("KBytes In/Out: " + QString::number(bIn/1000) + "K / " + QString::number(bOut/1000) + "K");
-    if (ConnectTime.elapsed()/1000 != 0)
-        videoAvgBwLabel->setText(tr("Average Kbps In/Out: ") + QString::number(bIn/ConnectTime.elapsed()/1000*8/1000) + "kbps / " + QString::number(bOut/ConnectTime.elapsed()/1000*8/1000) + "kbps");
     videoFramesInOutDiscLabel->setText(tr("Video Frames In/Out/Disc: ") + QString::number(fIn) + " / " + QString::number(fOut) + " / " + QString::number(fDiscIn) + " / " + QString::number(fDiscOut));
     if (ConnectTime.elapsed()/1000 != 0)
-        videoAvgFpsLabel->setText(tr("Average FPS In/Out: ") + QString::number(fIn/ConnectTime.elapsed()/1000) + " / " + QString::number(fOut/ConnectTime.elapsed()/1000));
+        videoAvgFpsLabel->setText(tr("Average FPS In/Out: ") + QString::number(fIn*1000/ConnectTime.elapsed()) + " / " + QString::number(fOut*1000/ConnectTime.elapsed()));
     if ((ConnectTime.elapsed()/1000 != 0) && (txClient != 0))
         videoWebcamFpsLabel->setText(tr("Webcam Frames Delivered/Dropped: ") + QString::number(wcDeliveredFrames) + " / " + QString::number(wcDroppedFrames));
 }
 
 
+void PhoneUIBox::updateVideoRtcpStatistics(int fractionLoss, int totalLoss)
+{
+    if ((!statsPopup) || (videoPkInLabel == 0))
+        return;
+
+    videoPkRtcpLabel->setText(tr("Packets Lost by Peer: ") + QString::number(fractionLoss) + " / " + QString::number(totalLoss));
+}
+
+
 void PhoneUIBox::closeStatisticsPopup()
 {
     if (!statsPopup)
@@ -1856,8 +1917,8 @@ void PhoneUIBox::closeStatisticsPopup()
     statsPopup->hide();
     delete statsPopup;
     statsPopup = NULL;
-    audioPkInOutLabel = audioBytesInOutLabel = audioAvgBwLabel = 0;
-    videoResLabel = videoPkOutLabel = videoPkInLabel = videoBytesInOutLabel = videoAvgBwLabel = videoFramesInOutDiscLabel = videoAvgFpsLabel = 0;
+    audioPkInOutLabel = audioPlayoutLabel = audioPkRtcpLabel = 0;
+    videoResLabel = videoPkOutLabel = videoPkInLabel = videoPkRtcpLabel = videoFramesInOutDiscLabel = videoAvgFpsLabel = 0;
 }
 
 
@@ -1867,8 +1928,8 @@ void PhoneUIBox::changeVolume(bool up_or_down)
     {
     default:
     case VOL_VOLUME:
-        if (gContext->GetNumSetting("MythControlsVolume", 0))
-            volume_control->AdjustCurrentVolume(up_or_down ? 2 : -2);
+//        if (gContext->GetNumSetting("MythControlsVolume", 0))
+//            volume_control->AdjustCurrentVolume(up_or_down ? 2 : -2);
         break;
     case VOL_MICVOLUME:
         break;
@@ -2021,7 +2082,7 @@ void PhoneUIBox::showVolume(bool on_or_off)
             {
             case VOL_VOLUME:
             default:
-                volume_status->SetUsed(volume_control->GetCurrentVolume());
+//                volume_status->SetUsed(volume_control->GetCurrentVolume());
                 break;
             case VOL_MICVOLUME:
                 volume_status->SetUsed(50);
@@ -2236,8 +2297,8 @@ PhoneUIBox::~PhoneUIBox(void)
     // Flush the events through the event queue now all the event-producing threads are closed
     QApplication::sendPostedEvents(this, 0);
     
-    if (volume_control)
-        delete volume_control;
+//    if (volume_control)
+//        delete volume_control;
     delete DirContainer;
     if (vmail)
         delete vmail;
