@@ -9,10 +9,6 @@
         <source>None</source>
         <translation>Inga</translation>
     </message>
-    <message>
-        <source>No Cover</source>
-        <translation>Ingen omslagsbild</translation>
-    </message>
     <message>
         <source>Done</source>
         <translation>Klart</translation>
@@ -67,14 +63,6 @@
         <source>1 - Lowest</source>
         <translation>1 - Lägsta</translation>
     </message>
-    <message>
-        <source>2</source>
-        <translation>2</translation>
-    </message>
-    <message>
-        <source>3</source>
-        <translation>3</translation>
-    </message>
     <message>
         <source>This is the &apos;level&apos; that MythVideo starts at. Any videos with a level at or below this will be shown in the list or while browsing by default. The Parental PIN should be set to limit changing of the default level.</source>
         <translation>Detta är nivån som barnlåset startar på. Filmer som har en nivå lägre än eller lika med denna kommer att visas i listorna medans filer som har en högre nivå kommer att döljas tills rätt PIN-kod har matats in.</translation>
@@ -93,48 +81,24 @@
     </message>
     <message>
         <source>If set, all files below the Myth Video directory will be displayed unless their extension is explicitly set to be ignored. </source>
-        <translation>Om funktionen är aktiverad, kommer alla filer som ligger under den tidigare specifierade katalogen att visas, såvida inte deras filändelse har satts upp för att ignoreras.</translation>
+        <translation>Visa alla filer som ligger under den tidigare specifierade katalogen såvida inte deras filändelse har satts upp för att ignoreras.</translation>
     </message>
     <message>
         <source>Video List browses files</source>
-        <translation>Visa även filer som inte sökts upp i filmhanteraren</translation>
+        <translation>Videolistvyn visar filer som inte sökts upp i videohanteraren</translation>
     </message>
     <message>
         <source>If set, this will cause the Video List screen to show all relevant files below the MythVideo starting directory whether they have been scanned or not.</source>
-        <translation>Om denna funktion är aktiverad kommer videolistvyn att visa alla relevanta filer som ligger under den tidigare specifierade katalogen och inte bara de filmer som har sökts upp under Filmhanteraren.</translation>
+        <translation>Videolistvyn visar alla relevanta filer som ligger under den tidigare specifierade katalogen och inte bara de filmer som har sökts upp i videohanteraren.</translation>
     </message>
     <message>
         <source>Default Player</source>
         <translation>Standardspelare</translation>
     </message>
-    <message>
-        <source>General Settings</source>
-        <translation>Generella inställningar</translation>
-    </message>
     <message>
         <source>Player Settings</source>
         <translation>Inställningar för spelare</translation>
     </message>
-    <message>
-        <source>Parental Pin:</source>
-        <translation>PIN-kod (barnlås):</translation>
-    </message>
-    <message>
-        <source>No Cover</source>
-        <translation>Ingen omslagsbild</translation>
-    </message>
-    <message>
-        <source>Unknown</source>
-        <translation>Okänd</translation>
-    </message>
-    <message>
-        <source>None</source>
-        <translation>Inga</translation>
-    </message>
-    <message>
-        <source>Unknown Rating</source>
-        <translation>Okänd rankning</translation>
-    </message>
     <message>
         <source>Newly scanned files are browsable by default</source>
         <translation>Nyscannade filer är bläddringsbara som standard</translation>
@@ -169,7 +133,7 @@
     </message>
     <message>
         <source>This directory must exist, and the user running MythVideo needs to have read/write permission to the directory.</source>
-        <translation>Katalogen måste existers och användaren som kör MythVideo måste ha skriv/läs-rättigheter till den.</translation>
+        <translation>Katalogen måste existera och användaren som kör MythVideo måste ha skriv/läs-rättigheter till den.</translation>
     </message>
     <message>
         <source>Video Manager</source>
@@ -245,8 +209,108 @@
         <translation>Standardvy för MythVideo. Andra vyer kan nås genom popup-menyn tillgänglig via MENY-knappen.</translation>
     </message>
     <message>
-        <source>videos</source>
-        <translation>filmer</translation>
+        <source>Video Browser browses files</source>
+        <translation>Bläddraren visar filer som inte sökts upp i videohanteraren</translation>
+    </message>
+    <message>
+        <source>If set, this will cause the Video Browser screen to show all relevant files below the MythVideo starting directory whether they have been scanned or not.</source>
+        <translation>Bläddraren visar alla relevanta filer som ligger under den tidigare specifierade katalogen och inte bara de filmer som har sökts upp i videohanteraren.</translation>
+    </message>
+    <message>
+        <source>Video Gallery browses files</source>
+        <translation>Videogalleriet visar filer som inte sökts upp i videohanteraren</translation>
+    </message>
+    <message>
+        <source>If set, this will cause the Video Gallery screen to show all relevant files below the MythVideo starting directory whether they have been scanned or not.</source>
+        <translation>Videogalleriet visar alla relevanta filer som ligger under den tidigare specifierade katalogen och inte bara de filmer som har sökts upp i videohanteraren.</translation>
+    </message>
+    <message>
+        <source>General Settings (1/2)</source>
+        <translation>Generella inställningar (1/2)</translation>
+    </message>
+    <message>
+        <source>General Settings (2/2)</source>
+        <translation>Generella inställningar (2/2)</translation>
+    </message>
+    <message>
+        <source>Video List Loads Video Meta Data</source>
+        <translation>Videolistvyn laddar videometadata</translation>
+    </message>
+    <message>
+        <source>If set along with Browse Files, this will cause the Video List to load any known video metadata from the database. Turning this off can greatly  speed up how long it takes to load the Video List tree</source>
+        <translation>Videolistvyn laddar alla kända videometadata från databasen. Att stänga av denna funktion kan minska tiden det tar att ladda videolistvyn väsentligt</translation>
+    </message>
+    <message>
+        <source>Sorting ignores case</source>
+        <translation>Skiftlägesokänslig sortering</translation>
+    </message>
+    <message>
+        <source>If set, case is ignored when sorting entries in a view.</source>
+        <translation>Ignorerar skillnad mellan stora och små bokstäver vid sortering i en vy.</translation>
+    </message>
+    <message>
+        <source>Show folders for database views</source>
+        <translation>Visa kataloger i databasvyer</translation>
+    </message>
+    <message>
+        <source>If set, sub folders of your video directory will be shown in supported views.</source>
+        <translation>Visar underkataloger till din videokatalog i de vyer som stödjer detta.</translation>
+    </message>
+    <message>
+        <source>Image cache size</source>
+        <translation>Bildcachestorlek</translation>
+    </message>
+    <message>
+        <source>This setting determines the number of images MythVideo will cache for views.</source>
+        <translation>Antal bilder som MythVideo cachar för vyer.</translation>
+    </message>
+    <message>
+        <source>^(The |A |An )</source>
+        <translation>^(The |A |An )</translation>
+    </message>
+    <message>
+        <source>All</source>
+        <translation>Alla</translation>
+    </message>
+    <message>
+        <source>Yes</source>
+        <translation>Ja</translation>
+    </message>
+    <message>
+        <source>No</source>
+        <translation>Nej</translation>
+    </message>
+    <message>
+        <source>Title</source>
+        <translation>Titel</translation>
+    </message>
+    <message>
+        <source>Year</source>
+        <translation>År</translation>
+    </message>
+    <message>
+        <source>User Rating</source>
+        <translation>Användarbetyg</translation>
+    </message>
+    <message>
+        <source>Runtime</source>
+        <translation>Speltid</translation>
+    </message>
+    <message>
+        <source>Filename</source>
+        <translation>Filnamn</translation>
+    </message>
+    <message>
+        <source>Video ID</source>
+        <translation>Video-ID</translation>
+    </message>
+    <message>
+        <source>Unknown</source>
+        <translation>Okänd</translation>
+    </message>
+    <message>
+        <source>None</source>
+        <translation>Inga</translation>
     </message>
 </context>
 <context>
@@ -478,14 +542,6 @@
         <source>No Videos</source>
         <translation>Inga filmer</translation>
     </message>
-    <message>
-        <source>No rating available.</source>
-        <translation>Ingen rankning tillgänglig.</translation>
-    </message>
-    <message>
-        <source>minutes</source>
-        <translation>minuter</translation>
-    </message>
     <message>
         <source>Watch This Video</source>
         <translation>Spela upp denna film</translation>
@@ -525,10 +581,6 @@
         <source>Ok</source>
         <translation>OK</translation>
     </message>
-    <message>
-        <source>Parental Pin:</source>
-        <translation>PIN-kod (barnlås):</translation>
-    </message>
 </context>
 <context>
     <name>VideoFilterDialog</name>
@@ -540,18 +592,10 @@
         <source>Result of this filter : No Videos</source>
         <translation>Resultat av detta filter: Inga videos</translation>
     </message>
-    <message>
-        <source>Unknown</source>
-        <translation>Okänd</translation>
-    </message>
     <message>
         <source>minutes</source>
         <translation>minuter</translation>
     </message>
-    <message>
-        <source>All</source>
-        <translation>Alla</translation>
-    </message>
     <message>
         <source>Save as default</source>
         <translation>Spara som standard</translation>
@@ -579,14 +623,6 @@
         <source>View Details</source>
         <translation>Visa detaljer</translation>
     </message>
-    <message>
-        <source>Plain View</source>
-        <translation>Vanlig vy</translation>
-    </message>
-    <message>
-        <source>Folder View</source>
-        <translation>Katalogvy</translation>
-    </message>
     <message>
         <source>Cancel</source>
         <translation>Avbryt</translation>
@@ -602,34 +638,6 @@
         <source>Cancel</source>
         <translation>Avbryt</translation>
     </message>
-    <message>
-        <source>minutes</source>
-        <translation>minuter</translation>
-    </message>
-    <message>
-        <source>Yes</source>
-        <translation>Ja</translation>
-    </message>
-    <message>
-        <source>No</source>
-        <translation>Nej</translation>
-    </message>
-    <message>
-        <source>No Cover</source>
-        <translation>Ingen omslagsbild</translation>
-    </message>
-    <message>
-        <source>Unknown</source>
-        <translation>Okänd</translation>
-    </message>
-    <message>
-        <source>None</source>
-        <translation>Ingen</translation>
-    </message>
-    <message>
-        <source>NR</source>
-        <translation>Oklassificerad</translation>
-    </message>
     <message>
         <source>delete failed</source>
         <translation>borttagning misslyckades</translation>
@@ -667,27 +675,8 @@
         <translation>Ta bort denna fil?</translation>
     </message>
 </context>
-<context>
-    <name>VideoSelected</name>
-    <message>
-        <source>No rating available.</source>
-        <translation>Ingen rankning tillgänglig.</translation>
-    </message>
-    <message>
-        <source>minutes</source>
-        <translation>minuter</translation>
-    </message>
-</context>
 <context>
     <name>VideoTree</name>
-    <message>
-        <source>Parental Pin:</source>
-        <translation>PIN-kod (barnlås):</translation>
-    </message>
-    <message>
-        <source>No files found</source>
-        <translation>Inga filer funna</translation>
-    </message>
     <message>
         <source>Select action</source>
         <translation>Välj åtgärd</translation>
