@@ -36,11 +36,9 @@ use vars qw($opt_h $opt_r $opt_d $opt_i $opt_v $opt_D $opt_M $opt_P);
 use Getopt::Std; 
 
 $title = "IMDB Query"; 
-$version = "v1.3.2";
+$version = "v1.3";
 $author = "Tim Harvey, Andrei Rjeousski";
 
-my @countries = qw(USA UK Canada Japan);
-
 binmode(STDOUT, ":utf8");
 
 # display usage
@@ -82,13 +80,6 @@ sub help {
    usage();
 }
 
-sub trim {
-   my ($str) = @_;
-   $str =~ s/^\s+//;
-   $str =~ s/\s+$//;
-   return $str;
-}
-
 # returns text within 'data' between 'beg' and 'end' matching strings
 sub parseBetween {
    my ($data, $beg, $end)=@_; # grab parameters
@@ -111,8 +102,6 @@ sub getMovieData {
    my ($movieid)=@_; # grab movieid parameter
    if (defined $opt_d) { printf("# looking for movie id: '%s'\n", $movieid);}
 
-   my $name_link_pat = qr'<a href="/name/[^"]*">([^<]*)</a>'m;
-
    # get the search results  page
    my $request = "http://www.imdb.com/title/tt" . $movieid . "/";
    if (defined $opt_d) { printf("# request: '%s'\n", $request); }
@@ -120,103 +109,117 @@ sub getMovieData {
    if (defined $opt_r) { printf("%s", $response); }
 
    # parse title and year
-   my $year = "";
    my $title = parseBetween($response, "<title>", "</title>");
-   if ($title =~ m#(.+) \((\d+).*\)#) # Note some years have a /II after them?
-   {
-      $title = $1;
-      $year = $2;
-   }
-   elsif ($title =~ m#(.+) \(\?\?\?\?\)#)
-   {
-      $title = $1;
-   }
+   $title =~ m#(.+) \((\d+).*\)#;  # Note some years have a /II after them?
+   $title = $1;
+   my $year = $2;
 
    # parse director 
-   my $data = parseBetween($response, ">Director:</h5>", "</div>");
-   if (!length($data)) {
-      $data = parseBetween($response, ">Directors:</h5>", "</div>");
-   }
-   my $director = join(",", ($data =~ m/$name_link_pat/g));
+   my $director = parseBetween($response, ">Directed by</b>", "/a><br>");
+   $director = parseBetween($director, "/\">", "<");
 
    # parse writer 
    # (Note: this takes the 'first' writer, may want to include others)
-   $data = parseBetween($response, ">Writers <a href=\"/wga\">(WGA)</a>:</h5>", "</div>");
-   if (!length($data)) {
-         $data = parseBetween($response, ">Writer:</h5>", "</div>");
-   }
-   if (!length($data)) {
-         $data = parseBetween($response, ">Writers:</h5>", "</div>");
-   }
-   my $writer = join(",", ($data =~ m/$name_link_pat/g));
+   my $writer = parseBetween($response, ">Writing credits</b>", "</table>");
+   $writer = parseBetween($writer, "/\">", "</");
 
    # parse plot
-   my $plot = parseBetween($response, ">Plot Outline:</h5> ", "</div>");
+   my $plot = parseBetween($response, ">Plot Outline:</b> ", "<br>");
    if (!$plot) {
-      $plot = parseBetween($response, ">Plot Summary:</h5> ", "</div>");
+      $plot = parseBetween($response, ">Plot Summary:</b> ", "<br>");
    }
 
    if ($plot) {
       # replace name links in plot (example 0388795)
+      my $name_link_pat = qr!<a href="/name/[^"]*">([^<]*)</a>!m;
       $plot =~ s/$name_link_pat/$1/g;
 
-      # replace title links
-      my $title_link_pat = qr!<a href="/title/[^"]*">([^<]*)</a>!m;
-      $plot =~ s/$title_link_pat/$1/g;
-
       # plot ends at first remaining link
-      my $plot_end = index($plot, "<a ");
+      my $plot_end = index($plot, "<a href=\"");
       if ($plot_end != -1) {
          $plot = substr($plot, 0, $plot_end);
       }
-      $plot = trim($plot);
    }
 
    # parse user rating
-   my $userrating = parseBetween($response, ">User Rating:</b>", "</b>");
+   my $userrating = parseBetween($response, ">User Rating:</b>", "> (");
    $userrating = parseBetween($userrating, "<b>", "/");
 
    # parse MPAA rating
    my $ratingcountry = "USA";
-   my $movierating = trim(parseBetween($response, ">MPAA</a>:</h5>", "</div>"));
+   my $movierating = parseBetween($response, ">MPAA</a>:</b> ", "<br>");
    if (!$movierating) {
-       $movierating = parseBetween($response, ">Certification:</h5>", "</div>");
+       $movierating = parseBetween($response, ">Certification:</b>", "<br>");
        $movierating = parseBetween($movierating, "certificates=$ratingcountry",
                                    "/a>");
        $movierating = parseBetween($movierating, ">", "<");
    }
 
    # parse movie length
-   my $rawruntime = trim(parseBetween($response, ">Runtime:</h5>", "</div>"));
-   my $runtime = trim(parseBetween($rawruntime, "", " min"));
-   for my $country (@countries) {
-      last if ($runtime =~ /^-?\d/);
-      $runtime = trim(parseBetween($rawruntime, "$country:", " min"));
-   }
+   my $runtime = parseBetween($response, ">Runtime:</b>\n", " min");
 
    # parse cast 
    #  Note: full cast would be from url: 
    #    www.imdb.com/title/<movieid>/fullcredits
+   my @actors;
    my $cast = "";
-   $data = parseBetween($response, "Cast overview, first billed only",
+   my $count = 0;
+   my $data = parseBetween($response, "Cast overview, first billed only:",
                                "/table>"); 
    if ($data) {
-      $cast = join(',', ($data =~ m/$name_link_pat/g));
+      my $beg = "/\">"; 
+      my $end = "</a>";
+      my $start = index($data, $beg);
+      my $finish = index($data, $end, $start);
+      my $actor;
+      while ($start != -1) {
+         $start += length($beg);
+         $actor = substr($data, $start, $finish - $start);
+         # add to array
+         $actors[$count++] = $actor;
+
+         # advance data to next movie
+         $data = substr($data, - (length($data) - $finish));
+         $start = index($data, $beg);
+         $finish = index($data, $end, $start + 1); 
+      }
+      $cast = join(',', @actors);
    }
    
    
    # parse genres 
    my $lgenres = "";
-   $data = parseBetween($response, "<h5>Genre:</h5>","</div>"); 
+   $count = 0;
+   $data = parseBetween($response, "<b class=\"ch\">Genre:</b>","<b class=\"ch\">User Comments:</b>"); 
    if ($data) {
       my $genre_pat = qr'/Sections/Genres/(?:[a-z ]+/)*">([^<]+)<'im;
       $lgenres = join(',', ($data =~ /$genre_pat/g));
    }
    
    # parse countries 
-   $data = parseBetween($response, "Country:</h5>","</div>"); 
-   my $country_pat = qr'/Sections/Countries/[A-Z]+/">([^<]+)</a>'i;
-   my $lcountries = join(",", ($data =~ m/$country_pat/g));
+   my @countries;
+   my $lcountries = "";
+   $count = 0;
+   $data = parseBetween($response, "<b class=\"ch\">Country:</b>","<br>"); 
+   if ($data) {
+      my $beg = "/\">"; 
+      my $end = "</a>";
+      my $start = index($data, $beg);
+      my $finish = index($data, $end, $start);
+      my $country;
+      while ($start != -1) {
+         $start += length($beg);
+         $country = substr($data, $start, $finish - $start);
+         # add to array
+         $countries[$count++] = $country;
+
+         # advance data to next movie
+         $data = substr($data, - (length($data) - $finish));
+         $start = index($data, $beg);
+         $finish = index($data, $end, $start + 1); 
+      }
+      $lcountries = join(',', @countries);
+   }
 
    # output fields (these field names must match what MythVideo is looking for)
    print "Title:$title\n";
@@ -243,8 +246,6 @@ sub getMoviePoster {
    my $response = get $request;
    if (defined $opt_r) { printf("%s", $response); }
 
-   if (!defined $response) {return;}
-
    my $uri = "";
 
    # look for references to impawards.com posters - they are high quality
@@ -262,16 +263,17 @@ sub getMoviePoster {
       if (defined $opt_d) { printf("# got %i bytes\n", length($impres)); }
       if (defined $opt_r) { printf("%s", $impres); }      
 
-      # making sure it isnt redirect
-      $uri = parseBetween($impres, "0;URL=..", "\">");
-      if ($uri ne "") {
-         if (defined $opt_d) { printf("# processing redirect to %s\n",$uri); }
-         # this was redirect
-         $impsite = $site . $uri;
-         $impres = get $impsite;
-      }
+	# making sure it isnt redirect
+	$uri = parseBetween($impres, "0;URL=..", "\">");
+	if ($uri ne "") {
+		if (defined $opt_d) { printf("# processing redirect to %s\n",$uri); }
+		# this was redirect
+                $impsite = $site . $uri;
+                $impres = get $impsite;
+	}
+
       
-      # do stuff normally
+      # do stuff normally	
       $uri = parseBetween($impres, "<img SRC=\"posters/", "\" ALT");
       # uri here is relative... patch it up to make a valid uri
       if (!($uri =~ /http:(.*)/ )) {
@@ -356,7 +358,10 @@ sub getMoviePoster {
 
       # now we get all other possible movie titles and store them in the titles array
       while($response =~ m/>([^>^\(]*)([ ]{0,1}\([^\)]*\)[^\(^\)]*[ ]{0,1}){0,1}\(informal title\)/g) {
-         $movie_titles[$k++] = trim($1);
+         $movie_titles[$k++] = $1;
+         chomp($movie_titles[$k-1]);
+         $movie_titles[$k-1] =~ s/^\s+//;
+         $movie_titles[$k-1] =~ s/\s+$//;
          if (defined $opt_d) { print "# Title: ".$movie_titles[$k-1]."\n"; }
       }
        
@@ -419,7 +424,7 @@ sub getMovieList {
    # check to see if we got a results page or a movie page
    #    looking for 'add=<movieid>" target=' which only exists
    #    in a movie description page 
-   my $movienum = parseBetween($response, "add=", "\">");
+   my $movienum = parseBetween($response, "add=", "\" target=");
    if ($movienum) {
        if (defined $opt_d) { printf("# redirected to movie page\n"); }
        my $movietitle = parseBetween($response, "<title>", "</title>"); 
@@ -433,16 +438,16 @@ sub getMovieList {
    #    possible matches are grouped in several catagories:  
    #        exact, partial, and approximate
    my $popular_results = parseBetween($response, "<b>Popular Titles</b>",
-                                              "</table>");
+                                              "</ol>");
    my $exact_matches = parseBetween($response, "<b>Titles (Exact Matches)</b>",
-                                              "</table>");
+                                              "</ol>");
    my $partial_matches = parseBetween($response, "<b>Titles (Partial Matches)</b>", 
-                                              "</table>");
-#   my $approx_matches = parseBetween($response, "<b>Titles (Approx Matches)</b>", 
-#                                               "</table>");
+                                              "</ol>");
+#   my $approx_matches = parseBetween($response, "<b>Approximate Matches</b>", 
+#                                               "</ol>");
    # parse movie list from matches
-   my $beg = "<tr>";
-   my $end = "</tr>";
+   my $beg = "<li>";
+   my $end = "</li>";
    my $count = 0;
    my @movies;
 
@@ -472,18 +477,29 @@ sub getMovieList {
       my $type = "";
       my $movienum = "";
 
-      if ($entry =~ m/<a href="\/title\/tt(\d+)\/.*\">(.+)<\/a> \((\d+)\)(?: \((.+)\))?/i) {
+      my $link_end = "</a>";
+      $fl_end = index($entry, $link_end);
+      $fl_end += length($link_end);
+      my $lhs = substr($entry, 0, $fl_end);
+      my $rhs = substr($entry, $fl_end);
+
+      if ($lhs =~ m/<a href="\/title\/tt(\d+)\/.*\">(.+)<\/a>/i) {
           $movienum = $1;
           $title = $2;
-          $year = $3;
-          $type = $4 if ($4);
       } else {
            if (defined $opt_d) {
-               print("Unrecognized entry format ($entry)\n");
+               print("Unrecognized entry format\n");
            }
            next;
       }
 
+      if ($rhs =~ m/\((\d+)\) \((.+)\)/) {
+          $year = $1;
+          $type = $2;
+      } elsif ($rhs =~ m/\((\d+)\)/) {
+          $year = $1;
+      }
+
       my $skip = 0;
 
       # fix broken 'tv=no' option
