@@ -32,7 +32,6 @@
 
 #include <mythtv/mythcontext.h>
 #include <mythtv/mythdbcon.h>
-#include <mythtv/inetcomms.h>
 #include <mythtv/httpcomms.h>
 
 
@@ -828,19 +827,8 @@ void Weather::setLocation(QString newLocale)
     // locale starts with "US" or locale is a zip code
     if (locale.left(2) == "US" || locale.left(5).contains(QRegExp("[0-9]{5,5}")) > 0)
     {
-        // update page to show US radar images
-        if (AnimatedImage)
-        {
-            AnimatedImage->SetSize(765, 500);
-            AnimatedImage->SetSkip(0, 58);
-        }
-
         if (container)
         {
-            texttype = (UITextType *) container->GetType("header5");
-            if (texttype)
-                texttype->SetText(tr("doppler radar"));
-
             for (int x = 1; x <= 9; x++)
             {
                 texttype = (UITextType *) container->GetType(QString("maplabel-%1")
@@ -856,37 +844,12 @@ void Weather::setLocation(QString newLocale)
                 if (texttype)
                     texttype->hide();
             }
-
-            imagetype = (UIImageType *) container->GetType("logo");
-            if (imagetype)
-            {
-                imagetype->SetSize(80, 60);
-                imagetype->LoadImage();
-            }
-
-            imagetype = (UIImageType *) container->GetType("radarbk");
-            if (imagetype)
-            {
-                imagetype->SetImage("mw-map.png");
-                imagetype->LoadImage();
-            }
         }
     }
     else
     {
-       // show satellite images
-       if (AnimatedImage)
-        {
-            AnimatedImage->SetSize(765, 500 - 58);
-            AnimatedImage->SetSkip(0, 0);
-        }
-
         if (container)
         {
-            texttype = (UITextType *) container->GetType("header5");
-            if (texttype)
-                texttype->SetText(tr("satellite image"));
-
             for (int x = 1; x <= 9; x++)
             {
                 texttype = (UITextType *) container->GetType(QString("maplabel-%1")
@@ -903,13 +866,6 @@ void Weather::setLocation(QString newLocale)
                     texttype->show();
             }
 
-            imagetype = (UIImageType *) container->GetType("logo");
-            if (imagetype)
-            {
-                imagetype->SetSize(100, 80);
-                imagetype->LoadImage();
-            }
-
             imagetype = (UIImageType *) container->GetType("radarbk");
             if (imagetype)
             {
@@ -2422,28 +2378,18 @@ float Weather::GetFloat(QString tag)
 
 bool Weather::GetWeatherData()
 {
-    
-    
-    QUrl weatherDataURL("http://www.msnbc.com/m/chnk/d/weather_d_src.asp?acid=" + locale);
 
-    INETComms *weatherData = new INETComms(weatherDataURL);
+    QString weatherDataURL = "http://www.msnbc.com/m/chnk/d/weather_d_src.asp?acid=" + locale;
 
-    VERBOSE(VB_NETWORK, QString("Grabbing weather from: %1").arg(weatherDataURL.toString()));
+    VERBOSE(VB_NETWORK, QString("Grabbing weather from: %1").arg(weatherDataURL));
 
-    while (!weatherData->isDone())
-    {
-        qApp->processEvents();
-        if (stopProcessing)
-            return false;
-
-    }
-    
     LayerSet *container = theme->GetSet("weatherpages");
     if (container)
         SetText(container, "updatetime", updated);
 
 
-    httpData = weatherData->getData();
+    httpData = HttpComms::getHttp(weatherDataURL, weatherTimeoutInt, 3, 3);
+
     if (httpData.find("this.swAcid = \"\";") != -1 ||
         httpData.find("<html>") != -1 ||
         httpData.find("Microsoft VBScript runtime") != -1 ||
@@ -2460,9 +2406,6 @@ bool Weather::GetWeatherData()
         return false;
     }
 
-    delete weatherData;
-    weatherData = NULL;
-
      // try to get some animated radar maps
      if (wantAnimated && GetAnimatedRadarMap())
          return true;
@@ -2476,51 +2419,26 @@ bool Weather::GetWeatherData()
 
 bool Weather::GetStaticRadarMap()
 {
-    QUrl weatherMapLink1URL(QString("http://www.weather.com/weather/map/%1"
+    QString weatherMapLink1URL = QString("http://www.weather.com/weather/map/%1"
                                     "?from=LAPmaps&setcookie=1 HTTP/1.1\n"
                                     "Connection: close\nHost: www.weather.com\n\n\n")
-                                    .arg(locale));
+                                    .arg(locale);
 
-    INETComms *weatherMapLink1 = new INETComms(weatherMapLink1URL);
-
-    while (!weatherMapLink1->isDone())
-    {
-        qApp->processEvents();
-        if (stopProcessing)
-            return false;
-    }
-
-    QString tempData = "";
-    tempData = weatherMapLink1->getData();
-
-    delete weatherMapLink1;
-    weatherMapLink1 = NULL;
+    QString tempData = HttpComms::getHttp(weatherMapLink1URL, weatherTimeoutInt, 3, 3);
 
     QString mapLoc = parseData(tempData, "if (isMinNS4) var mapNURL = \"", "\";");
     if (mapLoc == "<NULL>")
         return true;
      
-    QUrl weatherMapLink2URL("http://www.weather.com/" + mapLoc); 
+    QString weatherMapLink2URL = "http://www.weather.com/" + mapLoc;
      
     if (debug)
         cerr << "MythWeather: Grabbing Weather Map Link (part 2) From: " 
-             << weatherMapLink2URL.toString() << endl;
+             << weatherMapLink2URL << endl;
     
-    VERBOSE(VB_NETWORK, QString("Grabbing weather map(2) from: %1").arg(weatherMapLink2URL.toString()));
+    VERBOSE(VB_NETWORK, QString("Grabbing weather map(2) from: %1").arg(weatherMapLink2URL));
               
-    INETComms *weatherMapLink2 = new INETComms(weatherMapLink2URL);
-    while (!weatherMapLink2->isDone())
-    {
-        qApp->processEvents();
-        if (stopProcessing)
-            return false;
-
-    }
-
-    QString tempData2 = weatherMapLink2->getData();
-
-    delete weatherMapLink2;
-    weatherMapLink2 = NULL;
+    QString tempData2 = HttpComms::getHttp(weatherMapLink2URL, weatherTimeoutInt, 3, 3);
 
     QString imageLoc = parseData(tempData2, "<IMG NAME=\"mapImg\" SRC=\"http://image.weather.com", "\"");
     if (imageLoc == "<NULL>")
@@ -2610,6 +2528,14 @@ bool Weather::GetAnimatedRadarMap()
          return false;
      }
 
+     int imageCount = 5;
+     QString imagesList = parseData(tempData, "imagenames = new Array( '", ";");
+     if (imagesList != "<NULL>")
+     {
+         QStringList imageURLs = QStringList::split(",", imagesList);
+         imageCount = imageURLs.size();
+     }
+
      QString fileprefix = MythContext::GetConfDir();
 
      QDir dir(fileprefix);
@@ -2626,16 +2552,17 @@ bool Weather::GetAnimatedRadarMap()
          cerr << "MythWeather: Map File Prefix: " << fileprefix << endl;
 
      // delete existing radar maps
-     for (int x = 1; x <= 6; x++)
+     for (int x = 0; x < 10; x++)
          QFile::remove(QString(fileprefix + "/radar%1.jpg").arg(x));
 
      if (debug)
          cerr << "MythWeather: Copying Map Files from Server (" << imageLoc << ")...\n";
 
-     for (int x = 1; x <= 6; x++)
+     for (int x = 0; x < imageCount; x++)
      {
          QString sFile = QString(fileprefix + "/radar%1.jpg").arg(x);
-         sURL = QString("http://image.weather.com" + imageLoc + "%1L.jpg").arg(x);
+         sURL = QString("http://image.weather.com" + imageLoc + "%1L.jpg")
+		                .arg(x + 1);
          if (!HttpComms::getHttpFile(sFile, sURL, weatherTimeoutInt))
              cerr << "Failed to download image from:" << sURL << endl;
      }
