@@ -1,9 +1,16 @@
 <?php
-/***                                                                        ***\
-    recording_schedules.php                  Last Updated: 2005.04.09 (xris)
-
-    The Recording object, and a couple of related subroutines.
-\***                                                                        ***/
+/**
+ * The Schedule object and a couple of related subroutines.
+ *
+ * @url         $URL: svn+ssh://ijr@cvs.mythtv.org/var/lib/svn/trunk/mythplugins/mythweb/includes/recording_schedules.php $
+ * @date        $Date: 2006-09-10 17:08:56 -0400 (Sun, 10 Sep 2006) $
+ * @version     $Revision: 11113 $
+ * @author      $Author: xris $
+ * @license     GPL
+ *
+ * @package     MythWeb
+ *
+/**/
 
 // Include our dependencies -- these are probably called elsewhere, but require_once will handle it
     require_once 'includes/mythbackend.php';
@@ -61,24 +68,44 @@
 // Cleanup
     mysql_free_result($result);
 
-// Load all of the scheduled recordings.  We will need them at some point, so we
-// might as well get it overwith here.
+// Initialize
     global $Scheduled_Recordings, $Num_Conflicts, $Num_Scheduled;
     $Scheduled_Recordings = array();
+    $Num_Conflicts        = 0;
+    $Num_Scheduled        = 0;
+
+// Load all of the scheduled recordings.  We will need them at some point, so we
+// might as well get it overwith here.
     foreach (get_backend_rows('QUERY_GETALLPENDING', 2) as $key => $program) {
     // The offset entry
         if ($key === 'offset') {
             list($Num_Conflicts, $Num_Scheduled) = $program;
         }
-    // Normal entry:  $Scheduled_Recordings[chanid][starttime][]
+    // Normal entry:  $Scheduled_Recordings[callsign][starttime][]
         else {
-            $Scheduled_Recordings[$program[4]][$program[11]][] =& new Program($program);
+            $Scheduled_Recordings[$program[6]][$program[11]][] =& new Program($program);
         }
     }
 
-//
-//  Recording Schedule class
-//
+// Transcoder names
+    global $Transcoders;
+    $Transcoders = array();
+    $Transcoders[0] = 'Autodetect';
+    $result = mysql_query('SELECT r.id, r.name'
+                    .' FROM recordingprofiles AS r, profilegroups AS p'
+                    .' WHERE cardtype = "TRANSCODE"'
+                    .'   AND r.profilegroup = p.id')
+            or trigger_error('SQL Error: '.mysql_error(), FATAL);
+    while ($row = mysql_fetch_assoc($result)) {
+        if ($row['name'] != "RTjpeg/MPEG4" && $row['name'] != "MPEG2") {
+            $Transcoders[$row['id']] = $row['name'];
+        }
+    }
+    mysql_free_result($result);
+
+/**
+ * Recording Schedule class
+/**/
 class Schedule {
 
     var $recordid;
@@ -93,6 +120,7 @@ class Schedule {
     var $recpriority;
     var $category;
     var $maxnewest;
+    var $inactive;
     var $maxepisodes;
     var $autoexpire;
     var $startoffset;
@@ -113,13 +141,20 @@ class Schedule {
     var $findday;
     var $findtime;
     var $findid;
+    var $transcoder;
+    var $parentid;
 
     var $texttype;
     var $channel;
     var $will_record = false;
     var $class;         // css class, based on category and/or category_type
+    var $tsdefault;
 
+/**
+ * constructor
+/**/
     function Schedule($data) {
+        global $db;
     // Schedule object data -- just copy it into place
         if (is_object($data)) {
         // Not the right type of object?
@@ -135,20 +170,19 @@ class Schedule {
         }
     // Empty Schedule
         elseif (is_null($data)) {
+            $this->tsdefault = defined('default_rec_ts') ? default_rec_ts : 1.0;
             return;
         }
     // Something else
         else {
         // Data is a recordid -- load its contents
             if (!is_array($data) && $data > 0) {
-                $query = 'SELECT *, IF(type='.rectype_always.',-1,chanid) as chanid,'
-                        .' UNIX_TIMESTAMP(startdate)+TIME_TO_SEC(starttime) AS starttime,'
-                        .' UNIX_TIMESTAMP(enddate)+TIME_TO_SEC(endtime) AS endtime'
-                        .' FROM record WHERE recordid='.escape($data);
-                $result = mysql_query($query)
-                    or trigger_error('SQL Error: '.mysql_error(), FATAL);
-                $data = mysql_fetch_assoc($result);
-                mysql_free_result($result);
+                $data = $db->query_assoc('SELECT *, IF(type='.rectype_always.',-1,chanid)         AS chanid,
+                                                 UNIX_TIMESTAMP(startdate)+TIME_TO_SEC(starttime) AS starttime,
+                                                 UNIX_TIMESTAMP(enddate)+TIME_TO_SEC(endtime)     AS endtime
+                                            FROM record
+                                           WHERE recordid=?',
+                                         $data);
             }
         // Array?
             if (is_array($data) && isset($data['recordid'])) {
@@ -158,10 +192,16 @@ class Schedule {
             }
         }
 
+    // Custom power search needs to have fields split out
+        if ($this->search == searchtype_power) {
+            #########
+            /** @todo actually split out the fields! */
+        }
+
     // Add a generic "will record" variable, too
         $this->will_record = ($this->type && $this->type != rectype_dontrec) ? true : false;
 
-    // Turn type int a word
+    // Turn type into a word
         $this->texttype = $GLOBALS['RecTypes'][$this->type];
 
     // Do we have a chanid?  Load some info about it
@@ -174,14 +214,23 @@ class Schedule {
             $this->class = category_class($this);
     }
 
-/*
-    save:
-    save this schedule
-*/
+/**
+ * Save this schedule
+/**/
     function save($new_type) {
+        global $db;
     // Make sure that recordid is null if it's empty
-        if (empty($this->recordid))
+        if (empty($this->recordid)) {
             $this->recordid = NULL;
+            $this->findid   = (date('U', $this->starttime)/60/60/24) + 719528;
+        // Only auto-default these properties if we're not dealing with a
+        // search-based recording rule, otherwise take the values we
+        // received from the custom schedule input form
+            if (!$this->search) {
+                $this->findday  = (date('w', $this->starttime) + 1) % 7;
+                $this->findtime = date('G:i:s', $this->starttime);
+            }
+        }
     // Changing the type of recording
         if ($this->recordid && $this->type && $new_type != $this->type) {
         // Delete this schedule?
@@ -202,47 +251,61 @@ class Schedule {
     // Update the type, in case it changed
         $this->type = $new_type;
     // Update the record
-        $result = mysql_query('REPLACE INTO record (recordid,type,chanid,starttime,startdate,endtime,enddate,search,title,subtitle,description,profile,recpriority,category,maxnewest,maxepisodes,autoexpire,startoffset,endoffset,recgroup,dupmethod,dupin,station,seriesid,programid,autocommflag,findday,findtime,findid) values ('
-                                .escape($this->recordid, true)             .','
-                                .escape($this->type)                       .','
-                                .escape($this->chanid)                     .','
-                                .'FROM_UNIXTIME('.escape($this->starttime).'),'
-                                .'FROM_UNIXTIME('.escape($this->starttime).'),'
-                                .'FROM_UNIXTIME('.escape($this->endtime)  .'),'
-                                .'FROM_UNIXTIME('.escape($this->endtime)  .'),'
-                                .escape($this->search)                     .','
-                                .escape($this->title)                      .','
-                                .escape($this->subtitle)                   .','
-                                .escape($this->description)                .','
-                                .escape($this->profile)                    .','
-                                .escape($this->recpriority)                .','
-                                .escape($this->category)                   .','
-                                .escape($this->maxnewest)                  .','
-                                .escape($this->maxepisodes)                .','
-                                .escape($this->autoexpire)                 .','
-                                .escape($this->startoffset)                .','
-                                .escape($this->endoffset)                  .','
-                                .escape($this->recgroup)                   .','
-                                .escape($this->dupmethod)                  .','
-                                .escape($this->dupin)                      .','
-                                .escape($this->station)                    .',' // callsign!
-                                .escape($this->seriesid)                   .','
-                                .escape($this->programid)                  .','
-                                .escape($this->autocommflag)               .','
-                                .escape($this->findday)                    .','
-                                .escape($this->findtime)                   .','
-                                .escape($this->findid)                     .')')
-            or trigger_error('SQL Error: '.mysql_error(), FATAL);
+        $sh = $db->query('REPLACE INTO record (recordid,type,chanid,starttime,startdate,endtime,enddate,search,title,subtitle,description,profile,recpriority,category,maxnewest,inactive,maxepisodes,autoexpire,startoffset,endoffset,recgroup,dupmethod,dupin,station,seriesid,programid,autocommflag,findday,findtime,findid,autotranscode,transcoder,parentid,tsdefault,autouserjob1,autouserjob2,autouserjob3,autouserjob4)
+                                       VALUES (?,?,?,
+                                               FROM_UNIXTIME(?),FROM_UNIXTIME(?),FROM_UNIXTIME(?),FROM_UNIXTIME(?),
+                                               ?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?)',
+                         $this->recordid,
+                         $this->type,
+                         $this->chanid,
+                         $this->starttime,
+                         $this->starttime,
+                         $this->endtime,
+                         $this->endtime,
+                         $this->search,
+                         $this->title,
+                         $this->subtitle,
+                         $this->description,
+                         $this->profile,
+                         $this->recpriority,
+                         $this->category,
+                         $this->maxnewest,
+                         $this->inactive,
+                         $this->maxepisodes,
+                         $this->autoexpire,
+                         $this->startoffset,
+                         $this->endoffset,
+                         $this->recgroup,
+                         $this->dupmethod,
+                         $this->dupin,
+                         $this->station,  // callsign!
+                         $this->seriesid,
+                         $this->programid,
+                         $this->autocommflag,
+                         $this->findday,
+                         $this->findtime,
+                         $this->findid,
+                         $this->autotranscode,
+                         $this->transcoder,
+                         $this->parentid,
+                         $this->tsdefault,
+                         $this->autouserjob1,
+                         $this->autouserjob2,
+                         $this->autouserjob3,
+                         $this->autouserjob4
+                        );
     // Get the id that was returned
-        $recordid = mysql_insert_id();
+        $recordid = $sh->insert_id();
     // New recordid?
         if (empty($this->recordid))
             $this->recordid = $recordid;
     // Errors?
-        if (mysql_affected_rows() < 1 || $recordid < 1)
+        if ($sh->affected_rows() < 1 || $recordid < 1)
             trigger_error('Error creating recording schedule - no id was returned', FATAL);
         elseif ($program->recordid && $program->recordid != $recordid)
             trigger_error('Error updating recording schedule - different id was returned', FATAL);
+    // Finish
+        $sh->finish();
     // Notify the backend of the changes
         if ($this->recordid)
             backend_notify_changes($this->recordid);
@@ -250,37 +313,38 @@ class Schedule {
             backend_notify_changes();
     }
 
-/*
-    delete:
-    Delete this schedule
-*/
+/**
+ * Delete this schedule
+/**/
     function delete() {
+        global $db;
     // Delete this schedule from the database
-        $result = mysql_query('DELETE FROM record WHERE recordid='.escape($this->recordid))
-            or trigger_error('SQL Error: '.mysql_error().' [#'.mysql_errno().']', FATAL);
+        $sh = $db->query('DELETE FROM record WHERE recordid=?',
+                         $this->recordid);
     // Notify the backend of the changes
-        if (mysql_affected_rows())
+        if ($sh->affected_rows())
             backend_notify_changes($this->recordid);
+    // Finish
+        $sh->finish();
     // Remove this from the $Schedules array in memory
         unset($GLOBALS['Schedules'][$this->recordid]);
     }
 
-/*
-    details_list:
-    The "details list" for recording schedules.  Very similar to that for
-    programs, but with a few extra checks, and some information arranged
-    differently.
-*/
+/**
+ * The "details list" for recording schedules.  Very similar to that for
+ * programs, but with a few extra checks, and some information arranged
+ * differently.
+/**/
     function details_list() {
     // Start the list, and print the title and schedule type
         $str = "<dl class=\"details_list\">\n"
             // Title
               ."\t<dt>".t('Title').":</dt>\n"
-              ."\t<dd>".htmlentities($this->title, ENT_COMPAT, 'UTF-8')
+              ."\t<dd>".html_entities($this->title)
                        ."</dd>\n"
             // Type
               ."\t<dt>".t('Type').":</dt>\n"
-              ."\t<dd>".htmlentities($this->texttype, ENT_COMPAT, 'UTF-8')
+              ."\t<dd>".html_entities($this->texttype)
                        ."</dd>\n";
     // Only show these fields for recording types where they're relevant
         if (in_array($this->type, array(rectype_once, rectype_daily, rectype_weekly, rectype_override, rectype_dontrec))) {
@@ -293,31 +357,31 @@ class Schedule {
         // Subtitle
             if (preg_match('/\\S/', $this->subtitle)) {
                 $str .= "\t<dt>".t('Subtitle').":</dt>\n"
-                       ."\t<dd>".htmlentities($this->subtitle, ENT_COMPAT, 'UTF-8')
+                       ."\t<dd>".html_entities($this->subtitle)
                                 ."</dd>\n";
             }
         // Description
             if (preg_match('/\\S/', $this->description)) {
                 $str .= "\t<dt>".t('Description').":</dt>\n"
-                       ."\t<dd>".nl2br(htmlentities($this->description, ENT_COMPAT, 'UTF-8'))
+                       ."\t<dd>".nl2br(html_entities($this->description))
                                 ."</dd>\n";
             }
         // Rating
             if (preg_match('/\\S/', $this->rating)) {
                 $str .= "\t<dt>".t('Rating').":</dt>\n"
-                       ."\t<dd>".htmlentities($this->rating, ENT_COMPAT, 'UTF-8')
+                       ."\t<dd>".html_entities($this->rating)
                                 ."</dd>\n";
             }
         }
     // Category
         if (preg_match('/\\S/', $this->category)) {
             $str .= "\t<dt>".t('Category').":</dt>\n"
-                   ."\t<dd>".htmlentities($this->category, ENT_COMPAT, 'UTF-8')
+                   ."\t<dd>".html_entities($this->category)
                             ."</dd>\n";
         }
     // Rerun?
         if (!empty($this->previouslyshown)) {
-            $str .= "\t<dt>".t('Rerun').":</dt>\n"
+            $str .= "\t<dt>".t('Repeat').":</dt>\n"
                    ."\t<dd>".t('Yes')
                             ."</dd>\n";
         }
@@ -356,16 +420,29 @@ class Schedule {
             }
             $str .= "</dd>\n";
         }
+    // Recording Priority
+        if (preg_match('/\\S/', $this->recpriority)) {
+            $str .= "\t<dt>".t('Recording Priority').":</dt>\n"
+                   ."\t<dd>".html_entities($this->recpriority)
+                            ."</dd>\n";
+        }
     // Profile
         if (preg_match('/\\S/', $this->profile)) {
             $str .= "\t<dt>".t('Profile').":</dt>\n"
-                   ."\t<dd>".htmlentities($this->profile, ENT_COMPAT, 'UTF-8')
+                   ."\t<dd>".html_entities($this->profile)
+                            ."</dd>\n";
+        }
+    // Transcoder
+        if (preg_match('/\\S/', $this->transcoder)) {
+            global $Transcoders;
+            $str .= "\t<dt>".t('Transcoder').":</dt>\n"
+                   ."\t<dd>".html_entities(_or($Transcoders[$this->transcoder], '&nbsp;'))
                             ."</dd>\n";
         }
     // Recording Group
         if (!empty($this->recgroup)) {
             $str .= "\t<dt>".t('Recording Group').":</dt>\n"
-                   ."\t<dd>".htmlentities($this->recgroup, ENT_COMPAT, 'UTF-8')
+                   ."\t<dd>".html_entities($this->recgroup)
                             ."</dd>\n";
         }
     // Finish off the table and return
@@ -375,25 +452,39 @@ class Schedule {
 
 }
 
-/*
-    profile_select:
-    prints a <select> of the various recording profiles to choose from
-*/
+/**
+ * prints a <select> of the various recording profiles to choose from
+/**/
     function profile_select($this_profile, $name='profile') {
         echo "<select name=\"$name\">";
         foreach(array('Default', 'Live TV', 'High Quality', 'Low Quality') as $profile) {
-            echo '<option value="'.htmlentities($profile).'"';
+            echo '<option value="'.html_entities($profile).'"';
             if ($this_profile == $profile)
                 echo ' SELECTED';
-            echo '>'.htmlentities($profile).'</option>';
+            echo '>'.html_entities($profile).'</option>';
         }
         echo '</select>';
     }
 
-/*
-    recgroup_select:
-    prints a <select> of the various recgroups available
-*/
+/**
+ * prints a <select> of the various transcoders to choose from
+/**/
+    function transcoder_select($this_transcoder, $name='transcoder') {
+        global $Transcoders;
+        echo "<select name=\"$name\">";
+        foreach ($Transcoders as $transcoderid => $transcoder) {
+            echo '<option value="'.html_entities($transcoderid).'"';
+            if ($this_transcoder == $transcoderid) {
+                echo ' SELECTED';
+            }
+            echo '>'.html_entities($transcoder).'</option>';
+        }
+        echo '</select>';
+    }
+
+/**
+ * prints a <select> of the various recgroups available
+/**/
     function recgroup_select($this_group, $name = 'recgroup') {
         static $groups = array();
     // Load the recording groups?
@@ -418,13 +509,12 @@ class Schedule {
     // Print the <select>
         echo "<select name=\"$name\">";
         foreach($groups as $group) {
-            echo '<option value="'.htmlentities($group).'"';
+            echo '<option value="'.html_entities($group).'"';
             if ($this_group == $group)
                 echo ' SELECTED';
-            echo '>'.htmlentities($group).'</option>';
+            echo '>'.html_entities($group).'</option>';
         }
         echo '</select>';
     }
 
 
-?>
