@@ -1,17 +1,17 @@
-/***                                                                        ***\
-    init.js                                  Last Updated: 2005.01.23 (xris)
-
-    javascript initialization routine, and the content necessary to load the
-    other javascript files.
-\***                                                                        ***/
+/**
+ * javascript initialization routine, and the content necessary to load the
+ * other javascript files.
+ *
+ * @url         $URL: svn+ssh://ijr@cvs.mythtv.org/var/lib/svn/trunk/mythplugins/mythweb/js/init.js $
+ * @date        $Date: 2006-06-24 15:03:10 -0400 (Sat, 24 Jun 2006) $
+ * @version     $Revision: 10290 $
+ * @author      $Author: xris $
+ * @license     LGPL
+ *
+/**/
 
     window.onload = init;
 
-// Include some other modules
-    document.write('<script type="text/javascript" src="js/utils.js"></script>');
-    document.write('<script type="text/javascript" src="js/mouseovers.js"></script>');
-    document.write('<script type="text/javascript" src="js/visibility.js"></script>');
-
 // Define some global variables
     var isCSS, isW3C, isIE4, isNN4, isIE6, is_gecko, is_safari, is_khtml, is_opera;
     var on_load = new Array();                // An array of functions to be executed in init()
